05. Perspective
***************

.. figure:: images/05_perspective_projection.png
	:scale: 50 %
	:alt: 05_perspective_projection
	:align: center
	:figclass: align-center

	Perspective Projection

.. literalinclude:: ../../examples/GLWindow/05_perspective_projection.py
	:linenos:
